@@ -9,49 +9,54 @@ import contextlib
 import getpass
 
 import keyring
+from jaraco.context import suppress
+from more_itertools import always_iterable
 
-from . import Abode
+import jaraco.abode
+from . import Client
+from .helpers import urls
 from .helpers import constants as CONST
 from .helpers import timeline as TIMELINE
-from .exceptions import AbodeException
 
 _LOGGER = logging.getLogger('abodecl')
 
 
+@suppress(ImportError)
+def enable_color():
+    import colorlog
+
+    fmt = "%(asctime)s %(levelname)s (%(threadName)s) " "[%(name)s] %(message)s"
+    colorfmt = f"%(log_color)s{fmt}%(reset)s"
+    datefmt = '%Y-%m-%d %H:%M:%S'
+
+    handler = logging.getLogger().handlers[0]
+    handler.setFormatter(
+        colorlog.ColoredFormatter(
+            colorfmt,
+            datefmt=datefmt,
+            reset=True,
+            log_colors=dict(
+                DEBUG='cyan',
+                INFO='green',
+                WARNING='yellow',
+                ERROR='red',
+                CRITICAL='red',
+            ),
+        )
+    )
+
+
 def setup_logging(log_level=logging.INFO):
     """Set up the logging."""
     logging.basicConfig(level=log_level)
-    fmt = "%(asctime)s %(levelname)s (%(threadName)s) " "[%(name)s] %(message)s"
-    colorfmt = f"%(log_color)s{fmt}%(reset)s"
-    datefmt = '%Y-%m-%d %H:%M:%S'
 
     # Suppress overly verbose logs from libraries that aren't helpful
     logging.getLogger('requests').setLevel(logging.WARNING)
     logging.getLogger('urllib3').setLevel(logging.WARNING)
     logging.getLogger('aiohttp.access').setLevel(logging.WARNING)
 
-    try:
-        from colorlog import ColoredFormatter
-
-        logging.getLogger().handlers[0].setFormatter(
-            ColoredFormatter(
-                colorfmt,
-                datefmt=datefmt,
-                reset=True,
-                log_colors={
-                    'DEBUG': 'cyan',
-                    'INFO': 'green',
-                    'WARNING': 'yellow',
-                    'ERROR': 'red',
-                    'CRITICAL': 'red',
-                },
-            )
-        )
-    except ImportError:
-        pass
-
-    logger = logging.getLogger('')
-    logger.setLevel(log_level)
+    enable_color()
+    logging.getLogger('').setLevel(log_level)
 
 
 def build_parser():
@@ -212,8 +217,8 @@ def build_parser():
     return parser
 
 
-def _create_abode_instance(args):
-    return Abode(
+def _create_client_instance(args):
+    return Client(
         username=args.username,
         password=args.password,
         get_devices=args.mfa is None,
@@ -222,13 +227,13 @@ def _create_abode_instance(args):
 
 
 @contextlib.contextmanager
-def _log_errors_and_logout(abode):
+def _log_errors_and_logout(client):
     try:
-        yield abode
-    except abode.AbodeException as exc:
+        yield client
+    except jaraco.abode.Exception as exc:
         _LOGGER.error(exc)
     finally:
-        abode.logout()
+        client.logout()
 
 
 def _device_print(dev, append=''):
@@ -239,24 +244,19 @@ def _device_callback(dev):
     _device_print(dev, ", At: " + time.strftime("%Y-%m-%d %H:%M:%S"))
 
 
-def _timeline_callback(tl_json):
-    event_code = int(tl_json['event_code'])
+def _timeline_callback(resp):
+    event_code = int(resp['event_code'])
     if 5100 <= event_code <= 5199:
         # Ignore device changes
         return
 
-    _LOGGER.info(
-        "%s - %s at %s %s",
-        tl_json['event_name'],
-        tl_json['event_type'],
-        tl_json['date'],
-        tl_json['time'],
-    )
+    tmpl = '{event_name} - {event_type} at {date} {time}'
+    _LOGGER.info(tmpl.format_map(resp))
 
 
 class Dispatcher:
-    def __init__(self, abode, args):
-        self.abode = abode
+    def __init__(self, client, args):
+        self.client = client
         self.args = args
 
     def dispatch(self):
@@ -282,32 +282,32 @@ class Dispatcher:
     def login(self):
         if not self.args.mfa:
             return
-        self.abode.login(mfa_code=self.args.mfa)
+        self.client.login(mfa_code=self.args.mfa)
         # fetch devices from Abode
-        self.abode.get_devices()
+        self.client.get_devices()
 
     def output_current_mode(self):
         if not self.args.mode:
             return
-        _LOGGER.info("Current alarm mode: %s", self.abode.get_alarm().mode)
+        _LOGGER.info("Current alarm mode: %s", self.client.get_alarm().mode)
 
     def change_system_mode(self):
         if not self.args.arm:
             return
-        if self.abode.get_alarm().set_mode(self.args.arm):
+        if self.client.get_alarm().set_mode(self.args.arm):
             _LOGGER.info("Alarm mode changed to: %s", self.args.arm)
         else:
             _LOGGER.warning("Failed to change alarm mode to: %s", self.args.arm)
 
     def set_setting(self):
-        for setting in self.args.set or []:
+        for setting in always_iterable(self.args.set):
             keyval = setting.split("=")
-            if self.abode.set_setting(keyval[0], keyval[1]):
+            if self.client.set_setting(keyval[0], keyval[1]):
                 _LOGGER.info("Setting %s changed to %s", keyval[0], keyval[1])
 
     def switch_on(self):
-        for device_id in self.args.on or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.on):
+            device = self.client.get_device(device_id)
 
             if device:
                 if device.switch_on():
@@ -316,8 +316,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
     def switch_off(self):
-        for device_id in self.args.off or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.off):
+            device = self.client.get_device(device_id)
 
             if device:
                 if device.switch_off():
@@ -326,8 +326,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
     def lock(self):
-        for device_id in self.args.lock or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.lock):
+            device = self.client.get_device(device_id)
 
             if device:
                 if device.lock():
@@ -336,8 +336,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
     def unlock(self):
-        for device_id in self.args.unlock or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.unlock):
+            device = self.client.get_device(device_id)
 
             if device:
                 if device.unlock():
@@ -346,8 +346,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
     def output_json(self):
-        for device_id in self.args.json or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.json):
+            device = self.client.get_device(device_id)
 
             if device:
                 print(
@@ -364,12 +364,12 @@ class Dispatcher:
     def print_all_automations(self):
         if not self.args.automations:
             return
-        for automation in self.abode.get_automations():
+        for automation in self.client.get_automations():
             _device_print(automation)
 
     def enable_automation(self):
-        for automation_id in self.args.activate or []:
-            automation = self.abode.get_automation(automation_id)
+        for automation_id in always_iterable(self.args.activate):
+            automation = self.client.get_automation(automation_id)
 
             if automation:
                 if automation.enable(True):
@@ -378,8 +378,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find automation with id: %s", automation_id)
 
     def disable_automation(self):
-        for automation_id in self.args.deactivate or []:
-            automation = self.abode.get_automation(automation_id)
+        for automation_id in always_iterable(self.args.deactivate):
+            automation = self.client.get_automation(automation_id)
 
             if automation:
                 if automation.enable(False):
@@ -388,8 +388,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find automation with id: %s", automation_id)
 
     def trigger_automation(self):
-        for automation_id in self.args.trigger or []:
-            automation = self.abode.get_automation(automation_id)
+        for automation_id in always_iterable(self.args.trigger):
+            automation = self.client.get_automation(automation_id)
 
             if automation:
                 if automation.trigger():
@@ -398,8 +398,8 @@ class Dispatcher:
                 _LOGGER.warning("Could not find automation with id: %s", automation_id)
 
     def trigger_image_capture(self):
-        for device_id in self.args.capture or []:
-            device = self.abode.get_device(device_id)
+        for device_id in always_iterable(self.args.capture):
+            device = self.client.get_device(device_id)
 
             if device:
                 if device.capture():
@@ -412,9 +412,9 @@ class Dispatcher:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
     def save_camera_image(self):
-        for keyval in self.args.image or []:
+        for keyval in always_iterable(self.args.image):
             devloc = keyval.split("=")
-            device = self.abode.get_device(devloc[0])
+            device = self.client.get_device(devloc[0])
 
             if device:
                 try:
@@ -422,7 +422,7 @@ class Dispatcher:
                         _LOGGER.info(
                             "Saved image to %s for device id: %s", devloc[1], devloc[0]
                         )
-                except AbodeException as exc:
+                except jaraco.abode.Exception as exc:
                     _LOGGER.warning("Unable to save image: %s", exc)
             else:
                 _LOGGER.warning("Could not find device with id: %s", devloc[0])
@@ -430,20 +430,20 @@ class Dispatcher:
     def print_all_devices(self):
         if not self.args.devices:
             return
-        for device in self.abode.get_devices():
+        for device in self.client.get_devices():
             _device_print(device)
 
     def print_specific_devices(self):
         if not self.args.device:
             return
         for device_id in self.args.device:
-            device = self.abode.get_device(device_id)
+            device = self.client.get_device(device_id)
 
             if device:
                 _device_print(device)
 
                 # Register the specific devices if we decide to listen.
-                self.abode.events.add_device_callback(device_id, _device_callback)
+                self.client.events.add_device_callback(device_id, _device_callback)
             else:
                 _LOGGER.warning("Could not find device with id: %s", device_id)
 
@@ -454,20 +454,20 @@ class Dispatcher:
         if self.args.device is None:
             _LOGGER.info("Adding all devices to listener...")
 
-            for device in self.abode.get_devices():
-                self.abode.events.add_device_callback(
+            for device in self.client.get_devices():
+                self.client.events.add_device_callback(
                     device.device_id, _device_callback
                 )
 
-        self.abode.events.add_timeline_callback(TIMELINE.ALL, _timeline_callback)
+        self.client.events.add_timeline_callback(TIMELINE.ALL, _timeline_callback)
 
         _LOGGER.info("Listening for device and timeline updates...")
-        self.abode.events.start()
+        self.client.events.start()
         try:
             while True:
                 time.sleep(1)
         except KeyboardInterrupt:
-            self.abode.events.stop()
+            self.client.events.stop()
             _LOGGER.info("Device update listening stopped.")
 
 
@@ -478,10 +478,10 @@ def _get_password(args):
 
 
 def _get_or_set_password(username):
-    password = keyring.get_password(CONST.BASE_URL, username)
+    password = keyring.get_password(urls.BASE, username)
     if not password:
         password = getpass.getpass(f"Password for {username}: ")
-        keyring.set_password(CONST.BASE_URL, username, password)
+        keyring.set_password(urls.BASE, username, password)
     return password
 
 
@@ -492,5 +492,5 @@ def main():
 
     setup_logging(log_level=logging.INFO + 10 * (args.quiet - args.debug))
 
-    with _log_errors_and_logout(_create_abode_instance(args)) as abode:
-        Dispatcher(abode, args).dispatch()
+    with _log_errors_and_logout(_create_client_instance(args)) as client:
+        Dispatcher(client, args).dispatch()
