@@ -2,11 +2,11 @@
 import logging
 import copy
 
-from ..exceptions import AbodeException
-
-from ..devices.switch import AbodeDevice, AbodeSwitch
+import jaraco.abode
+from .switch import Switch
 from ..helpers import constants as CONST
 from ..helpers import errors as ERROR
+from ..helpers import urls
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,12 +25,14 @@ def state_from_panel(panel_state, area='1'):
 
 def create_alarm(panel_json, abode, area='1'):
     """Create a new alarm device from a panel response."""
-    return AbodeAlarm(state_from_panel(panel_json), abode, area)
+    return Alarm(state_from_panel(panel_json), abode, area)
 
 
-class AbodeAlarm(AbodeSwitch):
+class Alarm(Switch):
     """Class to represent the Abode alarm as a device."""
 
+    implements = CONST.TYPE_ALARM
+
     def __init__(self, json_obj, abode, area='1'):
         """Set up Abode alarm device."""
         super().__init__(json_obj, abode)
@@ -39,26 +41,24 @@ class AbodeAlarm(AbodeSwitch):
     def set_mode(self, mode):
         """Set Abode alarm mode."""
         if not mode:
-            raise AbodeException(ERROR.MISSING_ALARM_MODE)
+            raise jaraco.abode.Exception(ERROR.MISSING_ALARM_MODE)
 
         if mode.lower() not in CONST.ALL_MODES:
-            raise AbodeException(ERROR.INVALID_ALARM_MODE, CONST.ALL_MODES)
+            raise jaraco.abode.Exception(ERROR.INVALID_ALARM_MODE, CONST.ALL_MODES)
 
         mode = mode.lower()
 
-        response = self._abode.send_request(
-            "put", CONST.get_panel_mode_url(self._area, mode)
-        )
+        response = self._client.send_request("put", urls.panel_mode(self._area, mode))
 
         _LOGGER.debug("Set Alarm Home Response: %s", response.text)
 
         response_object = response.json()
 
         if response_object['area'] != self._area:
-            raise AbodeException(ERROR.SET_MODE_AREA)
+            raise jaraco.abode.Exception(ERROR.SET_MODE_AREA)
 
         if response_object['mode'] != mode:
-            raise AbodeException(ERROR.SET_MODE_MODE)
+            raise jaraco.abode.Exception(ERROR.SET_MODE_MODE)
 
         self._state['mode'][(self.device_id)] = response_object['mode']
 
@@ -82,17 +82,17 @@ class AbodeAlarm(AbodeSwitch):
 
     def switch_on(self):
         """Arm Abode to default mode."""
-        return self.set_mode(self._abode.default_mode)
+        return self.set_mode(self._client.default_mode)
 
     def switch_off(self):
         """Arm Abode to home mode."""
         return self.set_standby()
 
-    def refresh(self, url=CONST.PANEL_URL):
+    def refresh(self, url=urls.PANEL):
         """Refresh the alarm device."""
-        response_object = AbodeDevice.refresh(self, url)
+        response_object = super().refresh(url)
 
-        self._abode._panel.update(response_object[0])
+        self._client._panel.update(response_object[0])
 
         return response_object
 
