@@ -1,12 +1,16 @@
 """Abode binary sensor device."""
 
-from ..devices import AbodeDevice
+from typing import Optional, Union, Iterable
+
 from ..helpers import constants as CONST
+from . import base
 
 
-class AbodeBinarySensor(AbodeDevice):
+class BinarySensor(base.Device):
     """Class to represent an on / off, online/offline sensor."""
 
+    implements: Optional[Union[str, Iterable[str]]] = CONST.BINARY_SENSOR_TYPES
+
     @property
     def is_on(self):
         """
