@@ -4,18 +4,21 @@ import logging
 from shutil import copyfileobj
 import requests
 
-from ..exceptions import AbodeException
-from ..devices import AbodeDevice
+import jaraco
 from ..helpers import constants as CONST
 from ..helpers import errors as ERROR
 from ..helpers import timeline as TIMELINE
+from ..helpers import urls
+from . import base
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class AbodeCamera(AbodeDevice):
+class Camera(base.Device):
     """Class to represent a camera device."""
 
+    implements = CONST.TYPE_CAMERA
+
     _image_url = None
     _snapshot_base64 = None
 
@@ -29,24 +32,24 @@ class AbodeCamera(AbodeDevice):
             url = self._state['control_url']
 
         else:
-            raise AbodeException(ERROR.MISSING_CONTROL_URL)
+            raise jaraco.abode.Exception(ERROR.MISSING_CONTROL_URL)
 
         try:
-            response = self._abode.send_request("put", url)
+            response = self._client.send_request("put", url)
 
             _LOGGER.debug("Capture image response: %s", response.text)
 
             return True
 
-        except AbodeException as exc:
+        except jaraco.abode.Exception as exc:
             _LOGGER.warning("Failed to capture image: %s", exc)
 
         return False
 
     def refresh_image(self):
         """Get the most recent camera image."""
-        url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=self.device_id)
-        response = self._abode.send_request("get", url)
+        url = urls.TIMELINE_IMAGES_ID.format(device_id=self.device_id)
+        response = self._client.send_request("get", url)
 
         _LOGGER.debug("Get image response: %s", response.text)
 
@@ -65,17 +68,17 @@ class AbodeCamera(AbodeDevice):
         # Verify that the event code is of the "CAPTURE IMAGE" event
         event_code = timeline_json.get('event_code')
         if event_code != TIMELINE.CAPTURE_IMAGE['event_code']:
-            raise AbodeException(ERROR.CAM_TIMELINE_EVENT_INVALID)
+            raise jaraco.abode.Exception(ERROR.CAM_TIMELINE_EVENT_INVALID)
 
         # The timeline response has an entry for "file_path" that acts as the
         # location of the image within the Abode servers.
         file_path = timeline_json.get('file_path')
         if not file_path:
-            raise AbodeException(ERROR.CAM_IMAGE_REFRESH_NO_FILE)
+            raise jaraco.abode.Exception(ERROR.CAM_IMAGE_REFRESH_NO_FILE)
 
         # Perform a "head" request for the image and look for a
         # 302 Found response
-        response = self._abode.send_request("head", file_path)
+        response = self._client.send_request("head", file_path)
 
         if response.status_code != 302:
             _LOGGER.warning(
@@ -83,13 +86,13 @@ class AbodeCamera(AbodeDevice):
                 str(response.status_code),
                 response.text,
             )
-            raise AbodeException(ERROR.CAM_IMAGE_UNEXPECTED_RESPONSE)
+            raise jaraco.abode.Exception(ERROR.CAM_IMAGE_UNEXPECTED_RESPONSE)
 
         # The response should have a location header that is the actual
         # location of the image stored on AWS
         location = response.headers.get('location')
         if not location:
-            raise AbodeException(ERROR.CAM_IMAGE_NO_LOCATION_HEADER)
+            raise jaraco.abode.Exception(ERROR.CAM_IMAGE_NO_LOCATION_HEADER)
 
         self._image_url = location
 
@@ -109,7 +112,7 @@ class AbodeCamera(AbodeDevice):
                 str(response.status_code),
                 response.text,
             )
-            raise AbodeException(ERROR.CAM_IMAGE_REQUEST_INVALID)
+            raise jaraco.abode.Exception(ERROR.CAM_IMAGE_REQUEST_INVALID)
 
         with open(path, 'wb') as imgfile:
             copyfileobj(response.raw, imgfile)
@@ -118,12 +121,12 @@ class AbodeCamera(AbodeDevice):
 
     def snapshot(self):
         """Request the current camera snapshot as a base64-encoded string."""
-        url = f"{CONST.CAMERA_INTEGRATIONS_URL}{self._device_uuid}/snapshot"
+        url = f"{urls.CAMERA_INTEGRATIONS}{self._device_uuid}/snapshot"
 
         try:
-            response = self._abode.send_request("post", url)
+            response = self._client.send_request("post", url)
             _LOGGER.debug("Camera snapshot response: %s", response.text)
-        except AbodeException as exc:
+        except jaraco.abode.Exception as exc:
             _LOGGER.warning("Failed to get camera snapshot image: %s", exc)
             return False
 
@@ -162,7 +165,7 @@ class AbodeCamera(AbodeDevice):
         if self._state['privacy']:
             privacy = '1' if enable else '0'
 
-            path = CONST.PARAMS_URL + self.device_id
+            path = urls.PARAMS + self.device_id
 
             camera_data = {
                 'mac': self._state['camera_mac'],
@@ -171,7 +174,7 @@ class AbodeCamera(AbodeDevice):
                 'id': self.device_id,
             }
 
-            response = self._abode.send_request(
+            response = self._client.send_request(
                 method="put", path=path, data=camera_data
             )
             response_object = response.json()
@@ -179,10 +182,10 @@ class AbodeCamera(AbodeDevice):
             _LOGGER.debug("Camera Privacy Mode Response: %s", response.text)
 
             if response_object['id'] != self.device_id:
-                raise AbodeException(ERROR.SET_STATUS_DEV_ID)
+                raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
             if response_object['privacy'] != str(privacy):
-                raise AbodeException(ERROR.SET_PRIVACY_MODE)
+                raise jaraco.abode.Exception(ERROR.SET_PRIVACY_MODE)
 
             _LOGGER.info("Set camera %s privacy mode to: %s", self.device_id, privacy)
 
