@@ -7,7 +7,7 @@ import pytest
 from jaraco.collections import DictFilter
 
 import jaraco.abode
-from jaraco.abode.exceptions import AbodeException
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 import jaraco.abode.helpers.errors as ERROR
 from . import mock as MOCK
@@ -48,11 +48,11 @@ def all_devices():
 @pytest.fixture(autouse=True)
 def setup_URLs(m):
     # Set up mock URLs
-    m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-    m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-    m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-    m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
-    m.get(CONST.DEVICES_URL, json=all_devices())
+    m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+    m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+    m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+    m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+    m.get(urls.DEVICES, json=all_devices())
 
 
 class TestCamera:
@@ -61,7 +61,7 @@ class TestCamera:
     def camera_devices(self):
         return (
             device
-            for device in self.abode.get_devices()
+            for device in self.client.get_devices()
             if device.type_tag != CONST.DEVICE_ALARM
         )
 
@@ -78,7 +78,7 @@ class TestCamera:
             assert not device.no_response
 
             # Set up our direct device get url
-            device_url = CONST.DEVICE_URL.format(device_id=device.device_id)
+            device_url = urls.DEVICE.format(device_id=device.device_id)
 
             # Change device properties
             m.get(
@@ -133,8 +133,8 @@ class TestCamera:
             # Remove control URLs from JSON
             device._state = DictFilter(device._state, include_pattern='(?!control_url)')
 
-            # Test that AbodeException is raised with no control URLs
-            with pytest.raises(AbodeException) as exc:
+            # Test that jaraco.abode.Exception is raised with no control URLs
+            with pytest.raises(jaraco.abode.Exception) as exc:
                 device.capture()
             assert (exc.value.errcode, exc.value.message) == ERROR.MISSING_CONTROL_URL
 
@@ -149,7 +149,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up timeline response
-            url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
+            url = urls.TIMELINE_IMAGES_ID.format(device_id=device.device_id)
 
             m.get(url, json=[cam_type.timeline_event(device.device_id)])
             # Set up our file path response
@@ -168,7 +168,7 @@ class TestCamera:
             # Test that a bad file_path response header results in an exception
             m.head(cam_type.FILE_PATH, status_code=302)
 
-            with pytest.raises(jaraco.abode.AbodeException):
+            with pytest.raises(jaraco.abode.Exception):
                 device.refresh_image()
 
             # Test that a bad file_path response code results in an exception
@@ -178,27 +178,27 @@ class TestCamera:
                 headers={"Location": cam_type.LOCATION_HEADER},
             )
 
-            with pytest.raises(jaraco.abode.AbodeException):
+            with pytest.raises(jaraco.abode.Exception):
                 device.refresh_image()
 
             # Test that an an empty timeline event throws exception
-            url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
+            url = urls.TIMELINE_IMAGES_ID.format(device_id=device.device_id)
             m.get(
                 url,
                 json=[cam_type.timeline_event(device.device_id, file_path="")],
             )
 
-            with pytest.raises(jaraco.abode.AbodeException):
+            with pytest.raises(jaraco.abode.Exception):
                 device.refresh_image()
 
             # Test that an unexpected timeline event throws exception
-            url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
+            url = urls.TIMELINE_IMAGES_ID.format(device_id=device.device_id)
             m.get(
                 url,
                 json=[cam_type.timeline_event(device.device_id, event_code="1234")],
             )
 
-            with pytest.raises(jaraco.abode.AbodeException):
+            with pytest.raises(jaraco.abode.Exception):
                 device.refresh_image()
 
     def tests_camera_no_image_update(self, m):
@@ -209,7 +209,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up timeline response
-            url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
+            url = urls.TIMELINE_IMAGES_ID.format(device_id=device.device_id)
             m.get(url, json=[])
 
             # Refresh the image
@@ -227,7 +227,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up timeline response
-            url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
+            url = urls.TIMELINE_IMAGES_ID.format(device_id=device.device_id)
             m.get(url, json=[cam_type.timeline_event(device.device_id)])
 
             # Set up our file path response
@@ -252,7 +252,7 @@ class TestCamera:
 
             # Test that bad response returns False
             m.get(cam_type.LOCATION_HEADER, status_code=400)
-            with pytest.raises(jaraco.abode.AbodeException):
+            with pytest.raises(jaraco.abode.Exception):
                 device.image_to_file(path, get_image=True)
 
             # Test that the image fails to update returns False
@@ -270,9 +270,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up snapshot URL response
-            snapshot_url = (
-                f"{CONST.CAMERA_INTEGRATIONS_URL}{device.device_uuid}/snapshot"
-            )
+            snapshot_url = f"{urls.CAMERA_INTEGRATIONS}{device.device_uuid}/snapshot"
             m.post(snapshot_url, json=dict(base64Image='test'))
 
             # Retrieve a snapshot
@@ -297,9 +295,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up snapshot URL and image response
-            snapshot_url = (
-                f"{CONST.CAMERA_INTEGRATIONS_URL}{device.device_uuid}/snapshot"
-            )
+            snapshot_url = f"{urls.CAMERA_INTEGRATIONS}{device.device_uuid}/snapshot"
             image_response = b"this is a beautiful jpeg image"
             b64_image = str(base64.b64encode(image_response), "utf-8")
             m.post(snapshot_url, json=dict(base64Image=b64_image))
@@ -328,9 +324,7 @@ class TestCamera:
             assert device.status == CONST.STATUS_ONLINE
 
             # Set up snapshot URL and image response
-            snapshot_url = (
-                f"{CONST.CAMERA_INTEGRATIONS_URL}{device.device_uuid}/snapshot"
-            )
+            snapshot_url = f"{urls.CAMERA_INTEGRATIONS}{device.device_uuid}/snapshot"
             image_response = b"this is a beautiful jpeg image"
             b64_image = str(base64.b64encode(image_response), "utf-8")
             m.post(snapshot_url, json=dict(base64Image=b64_image))
@@ -352,22 +346,22 @@ class TestCamera:
         """Tests camera privacy mode."""
 
         # Get the IP camera and test we have it
-        device = self.abode.get_device(IPCAM.DEVICE_ID)
+        device = self.client.get_device(IPCAM.DEVICE_ID)
         assert device is not None
         assert device.status == CONST.STATUS_ONLINE
 
         # Set up params URL response for privacy mode on
-        m.put(CONST.PARAMS_URL + device.device_id, json=IPCAM.device(privacy=1))
+        m.put(urls.PARAMS + device.device_id, json=IPCAM.device(privacy=1))
 
         # Set privacy mode on
         assert device.privacy_mode(True)
 
         # Set up params URL response for privacy mode off
-        m.put(CONST.PARAMS_URL + device.device_id, json=IPCAM.device(privacy=0))
+        m.put(urls.PARAMS + device.device_id, json=IPCAM.device(privacy=0))
 
         # Set privacy mode off
         assert device.privacy_mode(False)
 
         # Test that an invalid privacy response throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.privacy_mode(True)
