@@ -1,6 +1,7 @@
 """Test the Abode device classes."""
 
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 
 import pytest
@@ -18,13 +19,13 @@ class TestDimmer:
 
     def tests_dimmer_device_properties(self, m):
         """Tests that dimmer light devices properties work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=DIMMER.device(
                 devid=DIMMER.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -35,10 +36,10 @@ class TestDimmer:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our dimmer
-        device = self.abode.get_device(DIMMER.DEVICE_ID)
+        device = self.client.get_device(DIMMER.DEVICE_ID)
 
         # Test our device
         assert device is not None
@@ -53,7 +54,7 @@ class TestDimmer:
         assert not device.is_on
 
         # Set up our direct device get url
-        device_url = CONST.DEVICE_URL.format(device_id=DIMMER.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=DIMMER.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -78,13 +79,13 @@ class TestDimmer:
 
     def tests_dimmer_status_changes(self, m):
         """Tests that dimmer device changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=DIMMER.device(
                 devid=DIMMER.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -95,10 +96,10 @@ class TestDimmer:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our dimmer
-        device = self.abode.get_device(DIMMER.DEVICE_ID)
+        device = self.client.get_device(DIMMER.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -106,7 +107,7 @@ class TestDimmer:
         assert not device.is_on
 
         # Set up control url response
-        control_url = CONST.BASE_URL + DIMMER.CONTROL_URL
+        control_url = urls.BASE + DIMMER.CONTROL_URL
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
@@ -140,5 +141,5 @@ class TestDimmer:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.switch_on()
