@@ -3,6 +3,7 @@
 import pytest
 
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 
 from .mock import login as LOGIN
@@ -18,13 +19,13 @@ class TestValve:
 
     def tests_switch_device_properties(self, m):
         """Tests that switch devices properties work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -34,10 +35,10 @@ class TestValve:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our power switch
-        device = self.abode.get_device(VALVE.DEVICE_ID)
+        device = self.client.get_device(VALVE.DEVICE_ID)
 
         # Test our device
         assert device is not None
@@ -48,7 +49,7 @@ class TestValve:
         assert not device.is_dimmable
 
         # Set up our direct device get url
-        device_url = CONST.DEVICE_URL.format(device_id=VALVE.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=VALVE.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -71,13 +72,13 @@ class TestValve:
 
     def tests_switch_status_changes(self, m):
         """Tests that switch device changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -87,10 +88,10 @@ class TestValve:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our power switch
-        device = self.abode.get_device(VALVE.DEVICE_ID)
+        device = self.client.get_device(VALVE.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -98,7 +99,7 @@ class TestValve:
         assert not device.is_on
 
         # Set up control url response
-        control_url = CONST.BASE_URL + VALVE.CONTROL_URL
+        control_url = urls.BASE + VALVE.CONTROL_URL
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
@@ -132,5 +133,5 @@ class TestValve:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.switch_on()
